import React, { useEffect, useState } from 'react';
import { Button, Card, Form, Input, Select } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { postSysOrg, putSysOrg, getSysOrgById } from "@/service/sysorg";
import { useSearchParams, useNavigate } from 'react-router-dom';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};
const tailFormItemLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0,
    },
    sm: {
      span: 16,
      offset: 8,
    },
  },
};

const { Option } = Select;

export default (props) => {

  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [form] = Form.useForm();
  const navigate = useNavigate();
  const [searchParams, setSearchParams] = useSearchParams();
  const id = searchParams.get("id");
  const [data, setDate] = useState();

  useEffect(() => {
    if (id) {
      getSysOrgById(id).then((res) => {
        form.setFieldsValue(res);
        setDate(res);
      });
    }
  }, [id]);

  const onFinish = (values) => {
    if (id) {
      startLoading();
      // 修改
      putTaOrgConfig(id, values).then((res) => {
        navigate(-1);
      });
    } else {
      // 新增
      postTaOrgConfig(values).then((res) => {
        navigate(-1);
      });
    }
  }


  return (
    <Card loading={loading}>
      <Form onFinish={onFinish} form={form} {...formItemLayout} scrollToFirstError style={{ maxWidth: '1000px' }}>
        <Form.Item
          name="orgId"
          label="机构ID"
        >
          <Input />
        </Form.Item>
        <Form.Item
          name="configCode"
          label="配置编码"
        >
          <Input />
        </Form.Item>
        <Form.Item
          name="configValue"
          label="配置项值"
        >
          <Input />
        </Form.Item>
        <Form.Item
          name="status"
          label="状态"
        >
          <Select
            style={{ width: '100%' }}
            placeholder="请选择状态"
          >
            <Option key={0}>不正常</Option>
            <Option key={1}>正常</Option>
          </Select>
        </Form.Item>
        <Form.Item {...tailFormItemLayout}>
          <Button loading={submiting} type="primary" htmlType="submit">
            保存
          </Button>
          <Button style={{ marginLeft: '2em' }} onClick={() => navigate(-1)}>
            返回
          </Button>
        </Form.Item>
      </Form>
    </Card>
  )
}


